@@ -1,12 +1,9 @@
 /* $XFree86: xc/lib/font/stubs/stubs.h,v 1.3 1999/12/15 01:14:36 robin Exp $ */
 
-/* This directory includes dummy entry for bdftopcf and mkfontdir */
-
 #include <stdio.h>
 #include <X11/fonts/fntfilst.h>
 #include <X11/fonts/font.h>
 
-
 #ifndef True
 #define True (-1)
 #endif
@@ -14,6 +11,13 @@
 #define False (0)
 #endif
 
+/* this probably works for Mach-O too, but probably not for PE */
+#if defined(__ELF__) && defined(__GNUC__) && (__GNUC__ >= 3)
+#define weak __attribute__((weak))
+#else
+#define weak
+#endif
+
 extern FontPtr find_old_font ( FSID id );
 extern int set_font_authorizations ( char **authorizations, 
 				     int *authlen, 
